@@ -1,7 +1,7 @@
 import pandas as pd
 import json
 
-csv = pd.read_csv('id.csv')
+csv = pd.read_csv('faker_ids/id.csv')
 csv = csv.values.tolist()
 
 def get_ids(n):
@@ -14,4 +14,4 @@ def get_ids(n):
         temp['mobileNumber'] = csv[i][3]    
         id.append(temp)
     return json.dumps(id, indent=4, sort_keys=True)
-print(get_ids(3))
\ No newline at end of file
+# print(get_ids(3))
\ No newline at end of file
